Stan Math Library: stan/math/rev/mat/fun/initialize_variable.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
initialize_variable.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::initialize_variable (var &variable, const var &value)
| Initialize variable to value. More...
template<int R, int C>
void | stan::math::initialize_variable (Eigen::Matrix< var, R, C > &matrix, const var &value)
| Initialize every cell in the matrix to the specified value. More...
template<typename T >
void | stan::math::initialize_variable (std::vector< T > &variables, const var &value)
| Initialize the variables in the standard vector recursively. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.